#!/usr/bin/env python2.7

import sys
sys.path.insert(0, '..')

import svn

#r = svn.RemoteClient('https://opsvn.openpeak.com/svn/adam2/trunk')
r = svn.LocalClient('/Users/dustin/development/php/adam2')

#print(r)

import pprint
pprint.pprint(r.info())

#r.checkout('/tmp/checkout_2')
#r.export('/tmp/export_1')

#l = svn.LocalClient('/Users/dustin/development/php/adam2')



from setuptools import setup, find_packages
import sys, os

import versioneer
versioneer.VCS = 'git'
versioneer.versionfile_source = 'svn/_version.py'
versioneer.versionfile_build = 'svn/_version.py'
versioneer.tag_prefix = ''
versioneer.parentdir_prefix = 'svn-'

setup(name='svn',
      version=versioneer.get_version(),
      description="Straight-forward Subversion wrapper.",
      long_description="""""",
      classifiers=[],
      keywords='svn subversion',
      author='Dustin Oprea',
      author_email='myselfasunder@gmail.com',
      url='',
      license='GPL 2',
      packages=find_packages(exclude=['test']),
      include_package_data=True,
      zip_safe=False,
      install_requires=[],
      entry_points="""""",
      cmdclass=versioneer.get_cmdclass(),
)



import subprocess
import logging

import svn

_logger = logging.getLogger('svn')


class CommonClient(object):
    def __init__(self, url_or_path, type_):
        self.__url_or_path = url_or_path

        if type_ not in (svn.T_URL, svn.T_PATH):
            raise ValueError("Type is invalid: %s" % (type_))

        self.__type = type_

    def run_command(self, subcommand, args, success_code=0, return_stderr=False, combine=False):
        cmd = ['svn', subcommand] + args

        _logger.debug("RUN: %s" % (cmd,))

        p = subprocess.Popen(cmd, 
                             stdout=subprocess.PIPE, 
                             stderr=subprocess.PIPE)

        (stdout, stderr) = p.communicate()
        if p.returncode != success_code:
            raise ValueError("Command failed with (%d): %s\n%s\n%s" % 
                             (p.returncode, cmd, stdout, stderr))

        s = stderr if return_stderr is True else stdout
        s = s.decode('ASCII')

        return s if combine is True else s.split("\n")

    def rows_to_dict(self, rows, lc=True):
        d = {}
        for row in rows:
            row = row.strip()
            if not row:
                continue

            pivot = row.index(': ')
            
            k = row[:pivot]
            v = row[pivot + 2:]

            if lc is True:
                k = k.lower()

            d[k] = v

        return d

    def info(self):
# TODO(dustin): Start using XML.
        info_rows = self.run_command('info', [self.__url_or_path])
        return self.rows_to_dict(info_rows)

    def export(self, path):
        self.run_command('export', [self.__url_or_path, path])

    @property
    def url(self):
        if self.__type != svn.T_URL:
            raise EnvironmentError("Only the remote-client has access to the URL.")

        return self.__url_or_path

    @property
    def path(self):
        if self.__type != svn.T_PATH:
            raise EnvironmentError("Only the local-client has access to the path.")

        return self.__url_or_path




# This file was generated by 'versioneer.py' (0.10+) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

versions = {'full_revisionid': '084fd68534d30e3459b2f68d3b7116b9514046b7', 'describe': '0.3.3-dirty', 'dash_dirty': '-dirty', 'distance': 0, 'default': '0.3.3-dirty', 'closest_tag_or_zero': '0.3.3', 'pep440': '0.3.3.dev0', 'long': '0.3.3-0-g084fd68-dirty', 'closest_tag': '0.3.3', 'dirty': True, 'short_revisionid': '084fd68', 'dash_distance': ''}


def get_versions(default={}, verbose=False):
    return versions
def get_version():
    return version_string_template % versions
